==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebCellPositionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCellPositionDescription } from "./WebCellPositionDescription";
/**
 * @hidden
 */
export let WebCellPositionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCellPositionDescriptionMetadata extends Base {
        static b(a) {
            if (WebCellPositionDescriptionMetadata.a == null) {
                WebCellPositionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCellPositionDescriptionMetadata.c(WebCellPositionDescriptionMetadata.a);
            }
            if (a.k(WebCellPositionDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebCellPositionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CellPosition");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("RowIndex", "Number:double");
            a.item("VisibleColumnIndex", "Number:double");
        }
        static d(a) {
            WebCellPositionDescriptionMetadata.b(a);
            a.ad("WebCellPosition", () => new WebCellPositionDescription());
            a.ac("WebCellPosition", WebCellPositionDescriptionMetadata.a);
        }
    }
    WebCellPositionDescriptionMetadata.$t = markType(WebCellPositionDescriptionMetadata, 'WebCellPositionDescriptionMetadata');
    WebCellPositionDescriptionMetadata.a = null;
    return WebCellPositionDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebCellPositionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCellPositionDescription } from "./WebCellPositionDescription";
/**
 * @hidden
 */
export let WebCellPositionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCellPositionDescriptionMetadata extends Base {
        static b(a) {
            if (WebCellPositionDescriptionMetadata.a == null) {
                WebCellPositionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCellPositionDescriptionMetadata.c(WebCellPositionDescriptionMetadata.a);
            }
            if (a.k(WebCellPositionDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebCellPositionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CellPosition");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("RowIndex", "Number:double");
            a.item("VisibleColumnIndex", "Number:double");
        }
        static d(a) {
            WebCellPositionDescriptionMetadata.b(a);
            a.ae("WebCellPosition", () => new WebCellPositionDescription());
            a.ad("WebCellPosition", WebCellPositionDescriptionMetadata.a);
        }
    }
    WebCellPositionDescriptionMetadata.$t = markType(WebCellPositionDescriptionMetadata, 'WebCellPositionDescriptionMetadata');
    WebCellPositionDescriptionMetadata.a = null;
    return WebCellPositionDescriptionMetadata;
})();
